==> snf-cloudcms-0.1.1.tar.gz: snf-cloudcms-0.1.1/cloudcms/synnefo_settings.py <==
# Copyright 2012 GRNET S.A. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that the following
# conditions are met:
#
#   1. Redistributions of source code must retain the above
#      copyright notice, this list of conditions and the following
#      disclaimer.
#
#   2. Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials
#      provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
# The views and conclusions contained in the software and
# documentation are those of the authors and should not be
# interpreted as representing official policies, either expressed
# or implied, of GRNET S.A.


CLOUDCMS_APPS = [
    'cloudcms',
    'cloudcmsblog',
    'pagination',

    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.admin',
    'django.contrib.admindocs',
    'django.contrib.sitemaps',

    'south',

    'feincms',
    'feincms.module.page',
    'feincms.module.medialibrary',
]
CLOUDCMS_MIDDLEWARES = [
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'pagination.middleware.PaginationMiddleware'
]
CLOUDCMS_STATICFILES = {
        'cloudcms': '',
        'feincms': ''
}
CLOUDCMS_CONTEXT_PROCESSORS = [
    'cloudcms.context_processors.application',
    'cloudcms.context_processors.cloudbar'
]


# Required additions in Django project settings

# keep compatibility with south v0.7.0 (available in debian squeeze)
try:
    from south import __version__
    if __version__ == "0.7":
        # south 0.7.0 requires full module name as keys while 0.7.3
        # uses the app names
        SOUTH_MIGRATION_MODULES = {
            'cloudcmsblog': 'cloudcms.migrate.cloudcmsblog',
            'feincms.module.page': 'cloudcms.migrate.page',
            'feincms.module.medialibrary': 'cloudcms.migrate.medialibrary',
        }
    else:
        SOUTH_MIGRATION_MODULES = {
            'cloudcmsblog': 'cloudcms.migrate.cloudcmsblog',
            'page': 'cloudcms.migrate.page',
            'medialibrary': 'cloudcms.migrate.medialibrary',
        }
except:
    pass


CLOUDBAR_URL = '/static/im/cloudbar/cloudbar.js'
CLOUDBAR_ACTIVE_SERVICE = 'okeanos_cms'

import os
SITE_ID = int(os.environ.get('CLOUDCMS_SITE_ID', 1))

==> snf-cloudcms-0.3.0.tar.gz: snf-cloudcms-0.3.0/cloudcms/synnefo_settings.py <==
# Copyright 2012 GRNET S.A. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that the following
# conditions are met:
#
#   1. Redistributions of source code must retain the above
#      copyright notice, this list of conditions and the following
#      disclaimer.
#
#   2. Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials
#      provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
# The views and conclusions contained in the software and
# documentation are those of the authors and should not be
# interpreted as representing official policies, either expressed
# or implied, of GRNET S.A.


CLOUDCMS_APPS = [
    'cloudcms',
    'cloudcmsblog',
    #'cloudcmsfiles',
    'pagination',

    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.admin',
    'django.contrib.admindocs',
    'django.contrib.sitemaps',

    'south',

    'feincms',
    'feincms.module.page',
    'feincms.module.medialibrary',
]
CLOUDCMS_MIDDLEWARES = [
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'pagination.middleware.PaginationMiddleware',
    'cloudcms.middleware.RequestMessagesMiddleware'
]
CLOUDCMS_STATICFILES = {
        'cloudcms': '',
        'feincms': ''
}
CLOUDCMS_CONTEXT_PROCESSORS = [
    'cloudcms.context_processors.application',
    'synnefo.lib.context_processors.cloudbar'
]


# Required additions in Django project settings

# keep compatibility with south v0.7.0 (available in debian squeeze)
try:
    from south import __version__
    if __version__ == "0.7":
        # south 0.7.0 requires full module name as keys while 0.7.3
        # uses the app names
        SOUTH_MIGRATION_MODULES = {
            'cloudcmsblog': 'cloudcms.migrate.cloudcmsblog',
            'feincms.module.page': 'cloudcms.migrate.page',
            'feincms.module.medialibrary': 'cloudcms.migrate.medialibrary',
        }
    else:
        SOUTH_MIGRATION_MODULES = {
            'cloudcmsblog': 'cloudcms.migrate.cloudcmsblog',
            'page': 'cloudcms.migrate.page',
            'medialibrary': 'cloudcms.migrate.medialibrary',
        }
except:
    pass


import os
SITE_ID = int(os.environ.get('CLOUDCMS_SITE_ID', 1))
